@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -122,7 +122,7 @@ BEGIN_KEY_NAME_TABLE(navpad)
   KEY_NAME_ENTRY(BM_KEY_LEFT, "Left"),
   KEY_NAME_ENTRY(BM_KEY_DOWN, "Down"),
   KEY_NAME_ENTRY(BM_KEY_RIGHT, "Right"),
-  KEY_NAME_ENTRY(BM_KEY_PRESS, "Center"),
+  KEY_NAME_ENTRY(BM_KEY_PRESS, "Select"),
 END_KEY_NAME_TABLE
 
 BEGIN_KEY_NAME_TABLE(wheels)
@@ -203,8 +203,8 @@ END_KEY_NAME_TABLES
 BEGIN_KEY_NAME_TABLES(orbit)
   KEY_NAME_TABLE(orbit),
   KEY_NAME_TABLE(dots),
-  KEY_NAME_TABLE(joystick),
-  KEY_NAME_SUBTABLE(display,8),
+  KEY_NAME_TABLE(navpad),
+  KEY_NAME_SUBTABLE(display,6),
 END_KEY_NAME_TABLES
 
 BEGIN_KEY_NAME_TABLES(NLS_Zoomax)
@@ -2995,13 +2995,20 @@ connectResource (BrailleDisplay *brl, const char *identifier) {
       .data=&baumEscapeOperations
     },
 
-    { /* Orbit 20 (20 cells) */
+    { /* Orbit Reader 20 (20 cells) */
       .vendor=0X0483, .product=0XA1D3,
       .configuration=1, .interface=0, .alternative=0,
       .inputEndpoint=1, .outputEndpoint=1,
       .data=&baumHid1Operations,
     },
 
+    { /* Orbit Reader 40 (40 cells) */
+      .vendor=0X0483, .product=0Xa366,
+      .configuration=1, .interface=0, .alternative=0,
+      .inputEndpoint=1, .outputEndpoint=1,
+      .data=&baumHid1Operations,
+    },
+
     { /* VarioPro 40 (40 cells) */
       .vendor=0X0904, .product=0X2000,
       .configuration=1, .interface=0, .alternative=0,
@@ -3256,6 +3263,7 @@ connectResource (BrailleDisplay *brl, const char *identifier) {
 
     { /* NLS eReader Zoomax (20 cells) */
       .vendor=0X1A86, .product=0X7523,
+      .parentVendor=0X1A40, .parentProduct=0X0101,
       .configuration=1, .interface=0, .alternative=0,
       .inputEndpoint=2, .outputEndpoint=2,
       .data=&baumEscapeOperations
